@@ -9,6 +9,7 @@ from src.mb_cruise_migration.framework.resolvers.file_format_resolver import FFL
 from src.mb_cruise_migration.framework.resolvers.file_type_resolver import FTLookup
 from src.mb_cruise_migration.framework.resolvers.version_description_resolver import VDLookup
 from src.mb_cruise_migration.framework.consts.const_initializer import ConstInitializer
+from src.mb_cruise_migration.logging.migration_log import MigrationLog
 from src.mb_cruise_migration.migration_properties import MigrationProperties
 
 from ncei_cruise_schema.entity.access_path import AccessPath
@@ -36,6 +37,7 @@ from tests.testutils import create_test_file, create_test_dataset, clean_cruise_
 
 class TestCruiseServiceCrud(unittest.TestCase):
     MigrationProperties("config_test.yaml")
+    MigrationLog()
 
     def tearDown(self):
         clean_cruise_db()
